@@ -115,12 +115,16 @@ Returns an array of strings representing all stream URLs found.
 Similar to B<get>() except it only returns a single stream representing 
 the first valid stream found.  
 
-Current options are:  I<"random"> and I<"noplaylists">.  By default, the 
-first ("best"?) stream is returned.  If I<"random"> is specified, then 
-a random one is selected from the list of streams found.  
+Current options are:  I<"random">, I<"nopls">, and I<"noplaylists">.  
+By default, the first ("best"?) stream is returned.  If I<"random"> is 
+specified, then a random one is selected from the list of streams found.  
+If I<"nopls"> is specified, and the stream to be returned is a ".pls" playlist, 
+it is first fetched and the first entry (or a random entry if I<"random"> is 
+specified) is returned.  This is needed by Fauxdacious Mediaplayer.
 If I<"noplaylists"> is specified, and the stream to be returned is a 
-"playlist" (.pls or .m3u? extension), it is first fetched and the first entry 
-in the playlist is returned.  This is needed by Fauxdacious Mediaplayer.
+"playlist" (either .pls or .m3u? extension), it is first fetched and the first 
+entry (or a random entry if I<"random"> is specified) in the playlist 
+is returned.
 
 =item $station->B<count>()
 
@@ -427,7 +431,8 @@ sub getURL   #LIKE GET, BUT ONLY RANDOMLY SELECT ONE TO RETURN:
 	my $self = shift;
 	my $arglist = (defined $_[0]) ? join('|',@_) : '';
 	my $idx = ($arglist =~ /\b\-?random\b/) ? int rand scalar @{$self->{'streams'}} : 0;
-	if ($arglist =~ /\b\-?noplaylists\b/ && ${$self->{'streams'}}[$idx] =~ /\.(pls|m3u8?)$/i) {
+	if (($arglist =~ /\b\-?nopls\b/ && ${$self->{'streams'}}[$idx] =~ /\.(pls)$/i)
+			|| ($arglist =~ /\b\-?noplaylists\b/ && ${$self->{'streams'}}[$idx] =~ /\.(pls|m3u8?)$/i)) {
 		my $plType = $1;
 		my $firstStream = ${$self->{'streams'}}[$idx];
 		print STDERR "-getURL($idx): NOPLAYLISTS and (".${$self->{'streams'}}[$idx].")\n"  if ($DEBUG);
@@ -448,33 +453,43 @@ sub getURL   #LIKE GET, BUT ONLY RANDOMLY SELECT ONE TO RETURN:
 			}
 		}
 		my @lines = split(/\r?\n/, $html);
-		$firstStream = '';
-		if ($plType =~ /pls/) {  #PLS:
-			my $firstTitle = '';
+		my @plentries = ();
+		my $firstTitle = '';
+		my $plidx = ($arglist =~ /\b\-?random\b/) ? 1 : 0;
+		if ($plType =~ /pls/i) {  #PLS:
 			foreach my $line (@lines) {
-				if ($line =~ m#^\s*File\d+\=(.+)$#) {
-					$firstStream ||= $1;
-				} elsif ($line =~ m#^\s*Title\d+\=(.+)$#) {
+				if ($line =~ m#^\s*File\d+\=(.+)$#o) {
+					push (@plentries, $1);
+				} elsif ($line =~ m#^\s*Title\d+\=(.+)$#o) {
 					$firstTitle ||= $1;
 				}
 			}
 			$self->{'title'} ||= $firstTitle;
-			print STDERR "-getURL(PLS): first=$firstStream= title=$firstTitle=\n"  if ($DEBUG);
-		} else {  #m3u8:
+			print STDERR "-getURL(PLS): title=$firstTitle= pl_idx=$plidx=\n"  if ($DEBUG);
+		} elsif ($arglist =~ /\b\-?noplaylists\b/) {  #m3u*:
 			(my $urlpath = ${$self->{'streams'}}[$idx]) =~ s#[^\/]+$##;
 			foreach my $line (@lines) {
-				if ($line =~ m#^\s*([^\#].+)$#) {
+				if ($line =~ m#^\s*([^\#].+)$#o) {
 					my $urlpart = $1;
-					$urlpart =~ s#^\s+##;
-					$urlpart =~ s#^\/##;
-					$firstStream = ($urlpart =~ m#https?\:#) ? $urlpart : ($urlpath . '/' . $urlpart);
-					last;
+					$urlpart =~ s#^\s+##o;
+					$urlpart =~ s#^\/##o;
+					push (@plentries, ($urlpart =~ m#https?\:#) ? $urlpart : ($urlpath . '/' . $urlpart));
+					last  unless ($plidx);
 				}
 			}
-			print STDERR "-getURL(m3u?): first=$firstStream=\n"  if ($DEBUG);
+			print STDERR "-getURL(m3u?): pl_idx=$plidx=\n"  if ($DEBUG);
 		}
-		return $firstStream || ${$self->{'streams'}}[$idx];
+		if ($plidx && $#plentries >= 0) {
+			$plidx = int rand scalar @plentries;
+		} else {
+			$plidx = 0;
+		}
+		$firstStream = (defined($plentries[$plidx]) && $plentries[$plidx]) ? $plentries[$plidx]
+				: ${$self->{'streams'}}[$idx];
+
+		return $firstStream;
 	}
+
 	return ${$self->{'streams'}}[$idx];
 }
 
